@@ -13,5 +13,4 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with desktopcouch.  If not, see <http://www.gnu.org/licenses/>.
-"""Tests for Documents API"""
-
+"""Tests for Records API."""
