@@ -61,6 +61,7 @@ def create_database(testcase):
 
 
 class TestMockedCouchDatabaseCreateStates(MockerTestCase):
+    """Mocked Couch Database tests for create= flag states."""
     def setUp(self):
         """Set up tests."""
         super(TestMockedCouchDatabaseCreateStates, self).setUp()
@@ -85,7 +86,7 @@ class TestMockedCouchDatabaseCreateStates(MockerTestCase):
         self.mocker.result({'update_seq': []})
 
         self.mocker.replay()
-        database = DesktopDatabase(self.dbname, uri=self.uri,
+        DesktopDatabase(self.dbname, uri=self.uri,
             record_factory=self.record_factory, create=True,
             server_class=self.server_class,
             oauth_tokens=self.oauth_tokens, ctx=self.ctx)
@@ -105,7 +106,7 @@ class TestMockedCouchDatabaseCreateStates(MockerTestCase):
         info["update_seq"]
         self.mocker.result({})
         self.mocker.replay()
-        database = DesktopDatabase(self.dbname, uri=self.uri,
+        DesktopDatabase(self.dbname, uri=self.uri,
             record_factory=self.record_factory, create=True,
             server_class=self.server_class,
             oauth_tokens=self.oauth_tokens, ctx=self.ctx)
@@ -140,7 +141,7 @@ class TestMockedCouchDatabaseCreateStates(MockerTestCase):
         self.mocker.result({})
 
         self.mocker.replay()
-        database = DesktopDatabase(self.dbname, uri=self.uri,
+        DesktopDatabase(self.dbname, uri=self.uri,
             record_factory=self.record_factory, create=False,
             server_class=self.server_class,
             oauth_tokens=self.oauth_tokens, ctx=self.ctx)
